@@ -428,9 +428,7 @@ MainWindow::initQML ()
     OsDependent &osd = Singletons::getRef().getOSD ();
     QRect rect = osd.getStartingSize ();
 
-    int webwidget_typeid =
     qmlRegisterType<WebWidget>("org.qgvdial.WebWidget", 1, 0, "MyWebWidget");
-    qDebug() << "Init: Webwidget type ID =" << webwidget_typeid;
 
     bool bTempFalse = false;
     int iTempZero = 0;
@@ -505,6 +503,9 @@ MainWindow::initQML ()
         this, SLOT  (onSigPinSettingChanges(bool, const QString &)));
     QObject::connect (gObj, SIGNAL (sigMsgBoxDone(bool)),
                       this, SLOT (onSigMsgBoxDone(bool)));
+    QObject::connect (
+        gObj      , SIGNAL  (sigSearchContacts(const QString &)),
+        &oContacts, SLOT (onSearchQueryChanged(const QString &)));
 
 #if DESKTOP_OS
     this->setFixedSize (this->size ());
@@ -632,7 +633,8 @@ MainWindow::loginCompleted (bool bOk, const QVariantList &varList)
         this->setPassword (strPass);
         QDeclarativeContext *ctx = this->rootContext();
         ctx->setContextProperty ("g_bIsLoggedIn", bLoggedIn);
-        ctx->setContextProperty ("g_bShowSettings", false);
+        bool bTemp = false;
+        ctx->setContextProperty ("g_bShowSettings", bTemp);
 
         // Fill up the combobox on the main page
         if ((!dbMain.getRegisteredNumbers (arrNumbers)) ||
@@ -1572,7 +1574,8 @@ void
 MainWindow::onSigMsgBoxDone (bool /*ok*/)
 {
     QDeclarativeContext *ctx = this->rootContext();
-    ctx->setContextProperty ("g_bShowMsg", false);
+    bool bTemp = false;
+    ctx->setContextProperty ("g_bShowMsg", bTemp);
 }//MainWindow::onSigMsgBoxDone
 
 void
